# -*- coding: utf-8 -*-
# Generated by Django 1.11 on 2018-12-18 12:08
from __future__ import unicode_literals

from django.conf import settings
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('djangoldp_skill', '0001_initial'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='skill',
            name='user',
        ),
        migrations.AddField(
            model_name='skill',
            name='users',
            field=models.ManyToManyField(blank=True, related_name='skills', to=settings.AUTH_USER_MODEL),
        ),
    ]
